@@ -4,29 +4,32 @@
 
 #include <stdio.h>
 #include <string.h>
+#include <langinfo.h>
 
 char const *ApplicationName("testlocale");
 bool multiByte(true);
 
+#ifdef CONFIG_I18N
 static char *
 foreign_str(char const *charset, char const *foreign)
 {
     size_t len(strlen(charset) + strlen(foreign));
-    char * str = new char [len + 8];
+    size_t size = len + 80;
+    char * str = new char [size];
 
-    sprintf (str, "\033%%/1\\%03o\\%03o%s\002%s",
+    snprintf(str, size, "\033%%/1\\%03zo\\%03zo%s\002%s",
              128 + len / 128, 128 + len % 128, charset, foreign);
 
     return str;
 }
 
 static void
-print_string(const YLChar *lstr, YUChar *ustr)
+print_string(const char *lstr, wchar_t *ustr)
 {
     printf ("In locale encoding: \"%s\"\n", lstr);
     printf ("In unicode encoding: \"");
 
-    for (YUChar * u(ustr); *u; ++u) printf("\\U%04x", *u);
+    for (wchar_t * u(ustr); *u; ++u) printf("\\U%04x", *u);
 
     puts ("\"");
 }
@@ -35,25 +38,35 @@ print_string(const YLChar *lstr, YUChar *ustr)
     printf("Rating for '" LocaleFragment "': %d\n", \
            YLocale::getRating(LocaleFragment));
 
+#endif
+
 int main() {
-    size_t ulen;
+#ifdef CONFIG_I18N
+    {
+        YLocale locale;
+        printf("Default locale: %s\n", YLocale::getLocaleName());
+        printf("nl_langinfo(%d): %s\n", CODESET, nl_langinfo(CODESET));
+    }
 
-    const YLChar *lstr("Mhrenkuter");
-    YUChar *ustr(YLocale("de_DE.iso-8859-1").
-                 unicodeString(lstr, strlen(lstr), ulen));
-    print_string(lstr, ustr);
+    {
+        size_t ulen;
 
-    lstr = foreign_str ("ISO8859-15", "Euro sign: ");
-    ustr = YLocale("de_DE.iso-8859-1").
-        unicodeString(lstr, strlen(lstr), ulen);
-    print_string(lstr, ustr);
+        const char *lstr("Mhrenkuter");
+        wchar_t *ustr(YLocale("de_DE.iso-8859-1").
+                     unicodeString(lstr, strlen(lstr), ulen));
+        print_string(lstr, ustr);
 
+        lstr = foreign_str ("ISO8859-15", "Euro sign: ");
+        ustr = YLocale("de_DE.iso-8859-1").
+            unicodeString(lstr, strlen(lstr), ulen);
+        print_string(lstr, ustr);
+    }
 
 /*
-    YLChar * utf8(YLocale("de_DE.utf8").localeString(unicode));
+    char * utf8(YLocale("de_DE.utf8").localeString(unicode));
     printf("utf8: %s\n", utf8);
 
-    YLChar * latin1(YLocale("de_DE.iso-8859-1").localeString(unicode));
+    char * latin1(YLocale("de_DE.iso-8859-1").localeString(unicode));
     printf("iso-8859-1: %s\n", latin1);
 */
 
@@ -69,7 +82,7 @@ int main() {
         TEST_RATING("de_DE@DEM");
         TEST_RATING("de_DE@euro");
     }
-    
+
     {
         YLocale locale("ru_RU.koi8r");
         printf("Current locale: %s\n", YLocale::getLocaleName());
@@ -82,6 +95,10 @@ int main() {
         TEST_RATING("ru_RU.cp1251");
         TEST_RATING("ru_RU.koi8r");
     }
-    
+#else
+    puts("I18N disabled.");
+#endif
     return 0;
 }
+
+// vim: set sw=4 ts=4 et:
