@@ -643,7 +643,9 @@ void WindowList::showFocused(int x, int y) {
         }
         getFrame()->setRequestedLayer(WinLayerAboveDock);
         getFrame()->setAllWorkspaces();
-        getFrame()->activateWindow(true);
+        getFrame()->wmRaise();
+        getFrame()->wmShow();
+        manager->setFocus(getFrame());
     }
 }
 
